aboutsummaryrefslogtreecommitdiff
path: root/tun/tun.go
diff options
context:
space:
mode:
Diffstat (limited to 'tun/tun.go')
-rw-r--r--tun/tun.go10
1 files changed, 5 insertions, 5 deletions
diff --git a/tun/tun.go b/tun/tun.go
index e203ba8..0ae53d0 100644
--- a/tun/tun.go
+++ b/tun/tun.go
@@ -23,16 +23,16 @@ type Device interface {
// Read one or more packets from the Device (without any additional headers).
// On a successful read it returns the number of packets read, and sets
// packet lengths within the sizes slice. len(sizes) must be >= len(buffs).
// A nonzero offset can be used to instruct the Device on where to begin
- // reading into each element of the buffs slice.
- Read(buffs [][]byte, sizes []int, offset int) (n int, err error)
+ // reading into each element of the bufs slice.
+ Read(bufs [][]byte, sizes []int, offset int) (n int, err error)
// Write one or more packets to the device (without any additional headers).
// On a successful write it returns the number of packets written. A nonzero
// offset can be used to instruct the Device on where to begin writing from
- // each packet contained within the buffs slice.
- Write(buffs [][]byte, offset int) (int, error)
+ // each packet contained within the bufs slice.
+ Write(bufs [][]byte, offset int) (int, error)
// MTU returns the MTU of the Device.
MTU() (int, error)
@@ -23,16 +23,16 @@ type Device interface {
// Read one or more packets from the Device (without any additional headers).
// On a successful read it returns the number of packets read, and sets
- // packet lengths within the sizes slice. len(sizes) must be >= len(buffs).
+ // packet lengths within the sizes slice. len(sizes) must be >= len(bufs).
// A nonzero offset can be used to instruct the Device on where to begin